@@ -1,6 +1,4 @@
-/* Clearlooks theme engine
- * Copyright (C) 2006 Richard Stellingwerff
- * Copyright (C) 2006 Daniel Borgman
+/* Clearlooks Glossy style
  * Copyright (C) 2006 Benjamin Berg
  * Copyright (C) 2007 Andrea Cimitan
  *
@@ -295,11 +293,14 @@ clearlooks_glossy_draw_button (cairo_t *cr,
 		
 		/* if (!(params->enable_glow && !params->active && !params->disabled)) */
 		if (!(params->prelight && params->enable_glow && !params->active))
+		{
 			if (!(params->disabled))
 				params->style_functions->draw_inset (cr, &params->parentbg, 0, 0, width-1, height-1, params->radius+1, params->corners);
 			else
 				/*Draw a lighter inset */
 				clearlooks_glossy_draw_light_inset (cr, &params->parentbg, 0, 0, width-1, height-1, params->radius+1, params->corners);
+		}
+
 		cairo_translate (cr, -0.5, -0.5);
 	}
 
@@ -1077,10 +1078,10 @@ clearlooks_glossy_draw_list_view_header (cairo_t *cr,
 		separator.horizontal = FALSE;
 		
 		if (params->ltr)
-			params->style_functions->draw_separator (cr, &colors->shade[3], params, &separator,
+			params->style_functions->draw_separator (cr, colors, params, &separator,
 			                                         width-1.5, 4.0, 2, height-8.0);
 		else
-			params->style_functions->draw_separator (cr, &colors->shade[3], params, &separator,
+			params->style_functions->draw_separator (cr, colors, params, &separator,
 			                                         1.5, 4.0, 2, height-8.0);
 	}
 }
@@ -1155,9 +1156,9 @@ clearlooks_glossy_draw_menuitem (cairo_t                   *cr,
 	CairoColor shade1, shade2, shade3;
 	cairo_pattern_t *pattern;
 
-	ge_shade_color (fill, 1.1, &shade1);
-	ge_shade_color (fill, 1.02, &shade2);
-	ge_shade_color (fill, 0.92, &shade3);
+	ge_shade_color (fill, 1.16, &shade1);
+	ge_shade_color (fill, 1.08, &shade2);
+	ge_shade_color (fill, 1.08, &shade3);
 	cairo_set_line_width (cr, 1.0);
 
 	ge_cairo_rounded_rectangle (cr, x+0.5, y+0.5, width - 1, height - 1, params->radius, params->corners);
