@@ -43,10 +43,9 @@
 #define LISTVIEW_SHADE_BOTTOM 0.96
 
 /* Toolbar */
-#define TOOLBAR_SHADE_TOP 1.05
+#define TOOLBAR_SHADE_TOP 1.04
 #define TOOLBAR_SHADE_CENTER_TOP 1.01
-#define TOOLBAR_SHADE_BOTTOM 0.96
-
+#define TOOLBAR_SHADE_BOTTOM 0.97
 
 static void
 clearlooks_draw_gummy_gradient (cairo_t          *cr,
@@ -77,9 +76,9 @@ clearlooks_draw_gummy_gradient (cairo_t          *cr,
 }
 
 static void
-clearlooks_set_mixed_color (cairo_t          *cr, 
-                            const CairoColor *color1, 
-                            const CairoColor *color2, 
+clearlooks_set_mixed_color (cairo_t          *cr,
+                            const CairoColor *color1,
+                            const CairoColor *color2,
                             gdouble mix_factor)
 {
 	CairoColor composite;
@@ -89,7 +88,7 @@ clearlooks_set_mixed_color (cairo_t          *cr,
 }
 
 static void
-clearlooks_gummy_draw_highlight_and_shade (cairo_t                *cr, 
+clearlooks_gummy_draw_highlight_and_shade (cairo_t                *cr,
                                            const CairoColor       *bg_color,
                                            const ShadowParameters *params,
                                            int width, int height, gdouble radius)
@@ -123,7 +122,7 @@ clearlooks_gummy_draw_highlight_and_shade (cairo_t                *cr,
 		cairo_set_source_rgba (cr, highlight.r, highlight.g, highlight.b, 0.5);
 	else
 		cairo_set_source_rgba (cr, shadow.r, shadow.g, shadow.b, 0.5);
-		
+
 	cairo_stroke (cr);
 
 	/* Bottom/Right highlight -- this includes the corners */
@@ -147,7 +146,7 @@ clearlooks_gummy_draw_top_left_highlight (cairo_t *cr, const CairoColor *color,
                                           const WidgetParameters *params,
                                           int width, int height, gdouble radius)
 {
-	CairoColor hilight; 
+	CairoColor hilight;
 
 	double light_top = params->ythickness-1,
 	       light_bottom = height - params->ythickness - 1,
@@ -204,12 +203,12 @@ clearlooks_gummy_draw_button (cairo_t                *cr,
 			radius = MIN (params->radius, MIN ((width - 2.0 - 2*xoffset) / 2.0 - 1.0, (height - 2.0 - 2*yoffset) / 2.0 - 1.0));
 
 			ge_cairo_rounded_rectangle (cr, 0, 0, width-1, height-1, radius+1, params->corners);
-			ge_shade_color (&params->parentbg, 0.96, &shadow);
+			ge_shade_color (&params->parentbg, 0.97, &shadow);
 			ge_cairo_set_color (cr, &shadow);
 			cairo_stroke (cr);
 
 			ge_cairo_rounded_rectangle (cr, 1, 1, width-2, height-2, radius+1, params->corners);
-			ge_shade_color (&params->parentbg, 0.92, &shadow);
+			ge_shade_color (&params->parentbg, 0.93, &shadow);
 			ge_cairo_set_color (cr, &shadow);
 			cairo_stroke (cr);
 		}
@@ -230,9 +229,9 @@ clearlooks_gummy_draw_button (cairo_t                *cr,
 		cairo_translate (cr, -0.5, -0.5);
 	}
 
-	clearlooks_draw_gummy_gradient (cr, xoffset+1, yoffset+1, 
-	                              width-(xoffset*2)-2, height-(yoffset*2)-2, 
-	                              &fill, params->disabled, radius, params->corners);
+	clearlooks_draw_gummy_gradient (cr, xoffset+1, yoffset+1,
+	                                width-(xoffset*2)-2, height-(yoffset*2)-2,
+	                                &fill, params->disabled, radius, params->corners);
 
 	/* Pressed button shadow */
 	if (params->active)
@@ -242,7 +241,7 @@ clearlooks_gummy_draw_button (cairo_t                *cr,
 
 		cairo_save (cr);
 
-		ge_cairo_rounded_rectangle (cr, xoffset+1, yoffset+1, width-(xoffset*2)-2, height, radius, 
+		ge_cairo_rounded_rectangle (cr, xoffset+1, yoffset+1, width-(xoffset*2)-2, height, radius,
 		                            params->corners & (CR_CORNER_TOPLEFT | CR_CORNER_TOPRIGHT | CR_CORNER_BOTTOMLEFT));
 		cairo_clip (cr);
 		cairo_rectangle (cr, xoffset+1, yoffset+1, width-(xoffset*2)-2, 3);
@@ -274,8 +273,8 @@ clearlooks_gummy_draw_button (cairo_t                *cr,
 	else
 		clearlooks_set_mixed_color (cr, &border_normal, &fill, 0.2);
 	ge_cairo_rounded_rectangle (cr, xoffset + 0.5, yoffset + 0.5,
-                                  width-(xoffset*2)-1, height-(yoffset*2)-1,
-                                  radius, params->corners);
+	                            width-(xoffset*2)-1, height-(yoffset*2)-1,
+	                            radius, params->corners);
 	cairo_stroke (cr);
 
 	if (!params->active)
@@ -302,12 +301,12 @@ clearlooks_gummy_draw_entry (cairo_t                *cr,
 	cairo_translate (cr, x+0.5, y+0.5);
 	cairo_set_line_width (cr, 1.0);
 
-	/* Fill the background (shouldn't have to) */
+	/* Fill the background to get the correct corners. */
 	cairo_rectangle (cr, -0.5, -0.5, width, height);
 	ge_cairo_set_color (cr, &params->parentbg);
 	cairo_fill (cr);
 
-	/* Fill the entry's base color (why isn't is large enough by default?) */
+	/* Fill with the base color, because it was just cleared above */
 	cairo_rectangle (cr, 1.5, 1.5, width-4, height-4);
 	ge_cairo_set_color (cr, base);
 	cairo_fill (cr);
@@ -323,7 +322,7 @@ clearlooks_gummy_draw_entry (cairo_t                *cr,
 	}
 	else
 	{
-		CairoColor shadow; 
+		CairoColor shadow;
 		ge_shade_color (&border, 0.92, &shadow);
 
 		cairo_set_source_rgba (cr, shadow.r, shadow.g, shadow.b, params->disabled ? 0.09 : 0.18);
@@ -458,14 +457,14 @@ clearlooks_gummy_draw_progressbar_fill (cairo_t                     *cr,
 	cairo_paint (cr);
 	cairo_pattern_destroy (pattern);
 
-	/* Draw the Strokes */
+	/* Draw the strokes */
 	while (tile_pos <= width+x_step)
 	{
 		cairo_move_to (cr, stroke_width/2-x_step, 0);
 		cairo_line_to (cr, stroke_width-x_step,   0);
 		cairo_line_to (cr, stroke_width/2-x_step, height);
 		cairo_line_to (cr, -x_step, height);
-		
+
 		cairo_translate (cr, stroke_width, 0);
 		tile_pos += stroke_width;
 	}
@@ -622,13 +621,13 @@ clearlooks_gummy_draw_scale_trough (cairo_t                *cr,
 	cairo_translate (cr, 1, 1);
 
 	if (!slider->lower && !slider->fill_level)
-		clearlooks_gummy_scale_draw_gradient (cr, 
+		clearlooks_gummy_scale_draw_gradient (cr,
 		                                      &colors->shade[2], /* bottom */
 		                                      &colors->shade[6], /* border */
 		                                      0, 0, trough_width, trough_height,
 		                                      slider->horizontal, TRUE);
 	else if (!slider->fill_level)
-		clearlooks_gummy_scale_draw_gradient (cr, 
+		clearlooks_gummy_scale_draw_gradient (cr,
 		                                      &colors->spot[1], /* bottom */
 		                                      &colors->spot[2], /* border */
 		                                      0, 0, trough_width, trough_height,
@@ -640,7 +639,7 @@ clearlooks_gummy_draw_scale_trough (cairo_t                *cr,
 		c1.a = 0.25;
 		c2.a = 0.25;
 
-		clearlooks_gummy_scale_draw_gradient (cr, 
+		clearlooks_gummy_scale_draw_gradient (cr,
 		                                      &c1, /* bottom */
 		                                      &c2, /* border */
 		                                      0, 0, trough_width, trough_height,
@@ -662,10 +661,18 @@ clearlooks_gummy_draw_tab (cairo_t                *cr,
 	const CairoColor    *stripe_border = &colors->spot[2];
 	const CairoColor    *fill;
 
-	cairo_pattern_t     *pattern;
+	cairo_pattern_t     *pattern = NULL;
 
 	double               radius;
-	double               strip_size;
+	
+	double               stripe_size = 2.0;
+	double               stripe_fill_size;
+	double               stripe_border_pos;
+
+	gboolean horizontal = FALSE;
+
+	if (params->ythickness == 3)
+		stripe_size = 3.0;
 
 	radius = MIN (params->radius, MIN ((width - 2.0) / 2.0, (height - 2.0) / 2.0));
 
@@ -683,7 +690,10 @@ clearlooks_gummy_draw_tab (cairo_t                *cr,
 	if (tab->gap_side == CL_GAP_TOP || tab->gap_side == CL_GAP_BOTTOM)
 	{
 		height += 3.0;
-		strip_size = 2.0/height; /* 2 pixel high strip */
+		stripe_fill_size = (tab->gap_side == CL_GAP_TOP ? stripe_size/height : stripe_size/(height-2));
+		stripe_border_pos = (tab->gap_side == CL_GAP_TOP ? (stripe_size+1.0)/height : (stripe_size+1.0)/(height-2));
+		
+		horizontal = TRUE;
 
 		if (tab->gap_side == CL_GAP_TOP)
 			cairo_translate (cr, 0.0, -3.0); /* gap at the other side */
@@ -691,9 +701,10 @@ clearlooks_gummy_draw_tab (cairo_t                *cr,
 	else
 	{
 		width += 3.0;
-		strip_size = 2.0/width;
+		stripe_fill_size = (tab->gap_side == CL_GAP_LEFT ? stripe_size/width : stripe_size/(width-2));
+		stripe_border_pos = (tab->gap_side == CL_GAP_LEFT ? (stripe_size+1.0)/width : (stripe_size+1.0)/(width-2));
 
-		if (tab->gap_side == CL_GAP_LEFT) 
+		if (tab->gap_side == CL_GAP_LEFT)
 			cairo_translate (cr, -3.0, 0.0); /* gap at the other side */
 	}
 
@@ -717,47 +728,80 @@ clearlooks_gummy_draw_tab (cairo_t                *cr,
 		shadow.corners = params->corners;
 
 		clearlooks_gummy_draw_highlight_and_shade (cr, &colors->bg[0], &shadow,
-		                                     width, height, radius);
+		                                           width, height, radius);
 	}
 
 	if (params->active)
 	{
 		CairoColor hilight;
 		CairoColor shade1, shade2, shade3;
-
-		pattern = cairo_pattern_create_linear (tab->gap_side == CL_GAP_LEFT   ? width-1  : 0,
-		                                       tab->gap_side == CL_GAP_TOP    ? height-2 : 1,
-		                                       tab->gap_side == CL_GAP_RIGHT  ? width    : 0,
-		                                       tab->gap_side == CL_GAP_BOTTOM ? height   : 0);
-
-		ge_cairo_rounded_rectangle (cr, 0, 0, width-1, height-1, radius, params->corners);
-
-		ge_shade_color (fill, 1.14, &hilight);
+		
+		ge_shade_color (fill, 1.15, &hilight);
 		ge_shade_color (fill, SHADE_TOP, &shade1);
 		ge_shade_color (fill, SHADE_CENTER_TOP, &shade2);
 		ge_shade_color (fill, SHADE_BOTTOM, &shade3);
 
-		cairo_pattern_add_color_stop_rgb (pattern, 0.0,        hilight.r, hilight.g, hilight.b);
-		cairo_pattern_add_color_stop_rgb (pattern, 1.0/height, hilight.r, hilight.g, hilight.b);
-		cairo_pattern_add_color_stop_rgb (pattern, 1.0/height, shade1.r, shade1.g, shade1.b);
-		cairo_pattern_add_color_stop_rgb (pattern, 0.45,       shade2.r, shade2.g, shade2.b);
-		cairo_pattern_add_color_stop_rgb (pattern, 0.45,       fill->r, fill->g, fill->b);
-		cairo_pattern_add_color_stop_rgb (pattern, 1.0,        shade3.r, shade3.g, shade3.b);
+		switch	(tab->gap_side)
+		{
+			case CL_GAP_TOP:
+				pattern = cairo_pattern_create_linear (0, height-2, 0, 0);
+				break;
+			case CL_GAP_BOTTOM:
+				pattern = cairo_pattern_create_linear (0, 1, 0, height);
+				break;
+			case CL_GAP_LEFT:
+				pattern = cairo_pattern_create_linear (width-2, 0, 1, 0);
+				break;
+			case CL_GAP_RIGHT:
+				pattern = cairo_pattern_create_linear (1, 0, width-2, 0);
+				break;
+		}
+
+		ge_cairo_rounded_rectangle (cr, 0, 0, width-1, height-1, radius, params->corners);
+
+		cairo_pattern_add_color_stop_rgb (pattern, 0.0, hilight.r, hilight.g, hilight.b);
+		cairo_pattern_add_color_stop_rgb (pattern, 1.0/(horizontal ? height : width), hilight.r, hilight.g, hilight.b);
+		cairo_pattern_add_color_stop_rgb (pattern, 1.0/(horizontal ? height : width), shade1.r, shade1.g, shade1.b);
+		cairo_pattern_add_color_stop_rgb (pattern, 0.45, shade2.r, shade2.g, shade2.b);
+		cairo_pattern_add_color_stop_rgb (pattern, 0.45, fill->r, fill->g, fill->b);
+		cairo_pattern_add_color_stop_rgb (pattern, 1.0, shade3.r, shade3.g, shade3.b);
 		cairo_set_source (cr, pattern);
 		cairo_fill (cr);
 		cairo_pattern_destroy (pattern);
 	}
 	else
 	{
-		/* Draw shade */
-		pattern = cairo_pattern_create_linear (tab->gap_side == CL_GAP_LEFT   ? width-2  : 0,
-		                                       tab->gap_side == CL_GAP_TOP    ? height-2 : 0,
-		                                       tab->gap_side == CL_GAP_RIGHT  ? width    : 0,
-		                                       tab->gap_side == CL_GAP_BOTTOM ? height   : 0);
+		CairoColor shade1;
+		
+		ge_shade_color (fill, SHADE_TOP, &shade1);
+		
+		switch	(tab->gap_side)
+		{
+			case CL_GAP_TOP:
+				pattern = cairo_pattern_create_linear (0, height-2, 0, 0);
+				break;
+			case CL_GAP_BOTTOM:
+				pattern = cairo_pattern_create_linear (0, 0, 0, height);
+				break;
+			case CL_GAP_LEFT:
+				pattern = cairo_pattern_create_linear (width-2, 0, 0, 0);
+				break;
+			case CL_GAP_RIGHT:
+				pattern = cairo_pattern_create_linear (0, 0, width, 0);
+				break;
+		}
 
 		ge_cairo_rounded_rectangle (cr, 0, 0, width-1, height-1, radius, params->corners);
 
-		cairo_pattern_add_color_stop_rgba (pattern, 0.0, stripe_fill->r, stripe_fill->g, stripe_fill->b, 0.5);
+		cairo_pattern_add_color_stop_rgba (pattern, 0.0, stripe_fill->r, stripe_fill->g, stripe_fill->b, 0.6);
+/*
+		cairo_pattern_add_color_stop_rgba (pattern, 1.0/(horizontal ? height : width), stripe_fill->r, stripe_fill->g, stripe_fill->b, 0.34);
+		cairo_pattern_add_color_stop_rgba (pattern, 1.0/(horizontal ? height : width), stripe_fill->r, stripe_fill->g, stripe_fill->b, 0.5);
+*/
+		cairo_pattern_add_color_stop_rgb  (pattern, stripe_fill_size, stripe_fill->r, stripe_fill->g, stripe_fill->b);
+		cairo_pattern_add_color_stop_rgba (pattern, stripe_fill_size, stripe_border->r, stripe_border->g, stripe_border->b, 0.72);
+		cairo_pattern_add_color_stop_rgba (pattern, stripe_border_pos, stripe_border->r, stripe_border->g, stripe_border->b, 0.72);
+		cairo_pattern_add_color_stop_rgb  (pattern, stripe_border_pos, shade1.r, shade1.g, shade1.b);
 		cairo_pattern_add_color_stop_rgba (pattern, 0.8, fill->r, fill->g, fill->b, 0.0);
 		cairo_set_source (cr, pattern);
 		cairo_fill (cr);
@@ -773,10 +817,21 @@ clearlooks_gummy_draw_tab (cairo_t                *cr,
 	}
 	else
 	{
-		pattern = cairo_pattern_create_linear (tab->gap_side == CL_GAP_LEFT   ? width-2  : 2,
-		                                       tab->gap_side == CL_GAP_TOP    ? height-2 : 2,
-		                                       tab->gap_side == CL_GAP_RIGHT  ? width    : 2,
-		                                       tab->gap_side == CL_GAP_BOTTOM ? height   : 2);
+		switch	(tab->gap_side)
+		{
+			case CL_GAP_TOP:
+				pattern = cairo_pattern_create_linear (2, height-2, 2, 2);
+				break;
+			case CL_GAP_BOTTOM:
+				pattern = cairo_pattern_create_linear (2, 2, 2, height);
+				break;
+			case CL_GAP_LEFT:
+				pattern = cairo_pattern_create_linear (width-2, 2, 2, 2);
+				break;
+			case CL_GAP_RIGHT:
+				pattern = cairo_pattern_create_linear (2, 2, width, 2);
+				break;
+		}
 
 		cairo_pattern_add_color_stop_rgb (pattern, 0.0, stripe_border->r, stripe_border->g, stripe_border->b);
 		cairo_pattern_add_color_stop_rgb (pattern, 0.8, border->r,        border->g,        border->b);
@@ -788,13 +843,14 @@ clearlooks_gummy_draw_tab (cairo_t                *cr,
 
 static void
 clearlooks_gummy_draw_separator (cairo_t                   *cr,
-                                 const CairoColor          *color,
+                                 const ClearlooksColors    *colors,
                                  const WidgetParameters    *widget,
                                  const SeparatorParameters *separator,
                                  int x, int y, int width, int height)
 {
+	CairoColor color = colors->shade[3];
 	CairoColor hilight;
-	ge_shade_color (color, 1.3, &hilight);
+	ge_shade_color (&color, 1.3, &hilight);
 
 	cairo_save (cr);
 	cairo_set_line_cap (cr, CAIRO_LINE_CAP_BUTT);
@@ -806,7 +862,7 @@ clearlooks_gummy_draw_separator (cairo_t                   *cr,
 
 		cairo_move_to         (cr, 0.0,   0.0);
 		cairo_line_to         (cr, width, 0.0);
-		ge_cairo_set_color    (cr, color);
+		ge_cairo_set_color    (cr, &color);
 		cairo_stroke          (cr);
 
 		cairo_move_to         (cr, 0.0,   1.0);
@@ -821,7 +877,7 @@ clearlooks_gummy_draw_separator (cairo_t                   *cr,
 
 		cairo_move_to         (cr, 0.0, 0.0);
 		cairo_line_to         (cr, 0.0, height);
-		ge_cairo_set_color    (cr, color);
+		ge_cairo_set_color    (cr, &color);
 		cairo_stroke          (cr);
 
 		cairo_move_to         (cr, 1.0, 0.0);
@@ -846,7 +902,7 @@ clearlooks_gummy_draw_slider (cairo_t                *cr,
 	int bar_x, i;
 	int shift_x;
 
-	cairo_set_line_width (cr, 1.0);	
+	cairo_set_line_width (cr, 1.0);
 	cairo_translate      (cr, x, y);
 
 	cairo_translate (cr, -0.5, -0.5);
@@ -954,8 +1010,8 @@ clearlooks_gummy_draw_scrollbar_stepper (cairo_t                          *cr,
 
 	fill = colors->bg[widget->state_type];
 	ge_shade_color(&fill, SHADE_TOP, &shade1);
-	ge_shade_color(&fill, SHADE_CENTER_TOP, &shade2); 
-	ge_shade_color(&fill, SHADE_BOTTOM, &shade3); 
+	ge_shade_color(&fill, SHADE_CENTER_TOP, &shade2);
+	ge_shade_color(&fill, SHADE_BOTTOM, &shade3);
 
 	cairo_pattern_add_color_stop_rgb(pattern, 0,   shade1.r, shade1.g, shade1.b);
 	cairo_pattern_add_color_stop_rgb(pattern, 0.5, shade2.r, shade2.g, shade2.b);
@@ -1058,7 +1114,7 @@ clearlooks_gummy_draw_scrollbar_slider (cairo_t                   *cr,
 	cairo_fill (cr);
 	cairo_pattern_destroy (pattern);
 
-	if (scrollbar->has_color) 
+	if (scrollbar->has_color)
 	{
 		cairo_set_source_rgba (cr, hilight.r, hilight.g, hilight.b, 0.2);
 		ge_cairo_stroke_rectangle (cr, 1.5, 1.5, width-3, height-3);
@@ -1150,10 +1206,10 @@ clearlooks_gummy_draw_list_view_header (cairo_t                        *cr,
 		separator.horizontal = FALSE;
 
 		if (params->ltr)
-			params->style_functions->draw_separator (cr, &colors->shade[3], params, &separator,
+			params->style_functions->draw_separator (cr, colors, params, &separator,
 			                                         width-1.5, 4.0, 2, height-8.0);
 		else
-			params->style_functions->draw_separator (cr, &colors->shade[3], params, &separator,
+			params->style_functions->draw_separator (cr, colors, params, &separator,
 			                                         1.5, 4.0, 2, height-8.0);
 	}
 }
@@ -1205,14 +1261,14 @@ clearlooks_gummy_draw_toolbar (cairo_t                 *cr,
 	{
 		/* Draw highlight */
 		cairo_move_to       (cr, 0, 0.5);
-		cairo_line_to       (cr, width-1, 0.5);
+		cairo_line_to       (cr, width-0.5, 0.5);
 		ge_cairo_set_color  (cr, &light);
 		cairo_stroke        (cr);
 	}
 
 	/* Draw shadow */
 	cairo_move_to       (cr, 0, height-0.5);
-	cairo_line_to       (cr, width-1, height-0.5);
+	cairo_line_to       (cr, width-0.5, height-0.5);
 	ge_cairo_set_color  (cr, dark);
 	cairo_stroke        (cr);
 }
@@ -1421,7 +1477,7 @@ clearlooks_gummy_draw_checkbox (cairo_t                  *cr,
                                 int x, int y, int width, int height)
 {
 	const CairoColor *border;
-	const CairoColor *dot; 
+	const CairoColor *dot;
 	gboolean inconsistent = FALSE;
 	gboolean draw_bullet = (checkbox->shadow_type == GTK_SHADOW_IN);
 
@@ -1437,7 +1493,7 @@ clearlooks_gummy_draw_checkbox (cairo_t                  *cr,
 	{
 		if (widget->prelight)
 			border = &colors->spot[2];
-		else		
+		else
 			border = &colors->shade[6];
 		dot    = &colors->text[GTK_STATE_NORMAL];
 	}
@@ -1447,25 +1503,25 @@ clearlooks_gummy_draw_checkbox (cairo_t                  *cr,
 
 	if (widget->xthickness > 2 && widget->ythickness > 2)
 	{
-		widget->style_functions->draw_inset (cr, &widget->parentbg, 0.5, 0.5, 
-                                  width-1, height-1, (widget->radius > 0)? 1 : 0, CR_CORNER_ALL);
-		
+		widget->style_functions->draw_inset (cr, &widget->parentbg, 0.5, 0.5,
+		                         width-1, height-1, (widget->radius > 0)? 1 : 0, CR_CORNER_ALL);
+
 		/* Draw the rectangle for the checkbox itself */
-		ge_cairo_rounded_rectangle (cr, 1.5, 1.5, 
-                                  width-3, height-3, (widget->radius > 0)? 1 : 0, CR_CORNER_ALL);
+		ge_cairo_rounded_rectangle (cr, 1.5, 1.5,
+		                            width-3, height-3, (widget->radius > 0)? 1 : 0, CR_CORNER_ALL);
 	}
 	else
 	{
 		/* Draw the rectangle for the checkbox itself */
-		ge_cairo_rounded_rectangle (cr, 0.5, 0.5, 
-                                  width-1, height-1, (widget->radius > 0)? 1 : 0, CR_CORNER_ALL);
+		ge_cairo_rounded_rectangle (cr, 0.5, 0.5,
+		                            width-1, height-1, (widget->radius > 0)? 1 : 0, CR_CORNER_ALL);
 	}
-	
+
 	if (!widget->disabled)
-	{		
+	{
 		if (widget->prelight)
 			clearlooks_set_mixed_color (cr, &colors->base[0], &colors->spot[1], 0.5);
-		else		
+		else
 			ge_cairo_set_color (cr, &colors->base[0]);
 		cairo_fill_preserve (cr);
 	}
@@ -1490,7 +1546,6 @@ clearlooks_gummy_draw_checkbox (cairo_t                  *cr,
 			cairo_curve_to (cr, 0.5 + (width*0.4), (height*0.7),
 			                    0.5 + (width*0.5), (height*0.4),
 			                    0.5 + (width*0.70), (height*0.25));
-
 		}
 
 		ge_cairo_set_color (cr, dot);
@@ -1498,26 +1553,114 @@ clearlooks_gummy_draw_checkbox (cairo_t                  *cr,
 	}
 }
 
+static void
+clearlooks_gummy_draw_focus (cairo_t *cr,
+                             const ClearlooksColors          *colors,
+                             const WidgetParameters          *widget,
+                             const FocusParameters           *focus,
+                             int x, int y, int width, int height)
+{
+	double xoffset, yoffset;
+	const CairoColor *fill = &focus->color;
+	CairoColor shade1, shade2, shade3;
+	CairoColor border;
+	boolean fill_focus = TRUE; /* Useful in the future for selected cells */
+	boolean stroke_focus = TRUE; /* Useful? */
+	double radius = widget->radius - 1.0;
+	
+	ge_shade_color (fill, 0.65, &border);
+	ge_shade_color (fill, SHADE_TOP, &shade1);
+	ge_shade_color (fill, SHADE_CENTER_TOP, &shade2);
+	ge_shade_color (fill, SHADE_BOTTOM, &shade3);
+	
+	/* Do some useful things to adjust focus */
+	switch (focus->type)
+	{
+		case CL_FOCUS_BUTTON:
+			xoffset = -0.5;
+			yoffset = -0.5;
+			break;
+		case CL_FOCUS_LABEL:
+			xoffset = 0.5;
+			yoffset = 0.5;
+			break;
+		case CL_FOCUS_TREEVIEW_DND:
+			xoffset = 1.5;
+			yoffset = 1.5;
+			break;
+		case CL_FOCUS_TREEVIEW_HEADER:
+			cairo_translate (cr, -1, 0);
+			xoffset = 1.5;
+			yoffset = 1.5;
+			break;
+		case CL_FOCUS_TREEVIEW_ROW:
+			fill_focus = FALSE;
+			xoffset = 1.5;
+			yoffset = 1.5;
+			break;
+		case CL_FOCUS_TAB:
+			xoffset = 1.5;
+			yoffset = 1.5;
+			break;
+		case CL_FOCUS_SCALE:
+			xoffset = 1.5;
+			yoffset = 1.5;
+			break;
+		default:
+			xoffset = 1.5;
+			yoffset = 1.5;
+			break;
+	};
+	
+	cairo_set_line_width (cr, 1.0);
+	
+	ge_cairo_rounded_rectangle (cr, x+xoffset, y+yoffset, width - xoffset*2, height - yoffset*2, radius, widget->corners);
+	
+	if (fill_focus)
+	{
+		cairo_pattern_t *pattern;
+		
+		cairo_translate (cr, x, y);
+		
+		pattern = cairo_pattern_create_linear (0, 0, 0, height);
+		cairo_pattern_add_color_stop_rgba (pattern, 0.0, shade1.r, shade1.g, shade1.b, 0.2);
+		cairo_pattern_add_color_stop_rgba (pattern, 0.5, shade2.r, shade2.g, shade2.b, 0.2);
+		cairo_pattern_add_color_stop_rgba (pattern, 0.5, fill->r,  fill->g,  fill->b,  0.2);
+		cairo_pattern_add_color_stop_rgba (pattern, 1.0, shade3.r, shade3.g, shade3.b, 0.2);
+		cairo_set_source (cr, pattern);
+		cairo_fill_preserve (cr);
+		cairo_pattern_destroy (pattern);
+	}
+	
+	if (stroke_focus)
+	{
+		border.a = 0.6;
+		ge_cairo_set_color (cr, &border);
+		cairo_stroke(cr);
+	}
+}
+
 void
 clearlooks_register_style_gummy (ClearlooksStyleFunctions *functions)
 {
-	functions->draw_button              = clearlooks_gummy_draw_button;
-	functions->draw_entry               = clearlooks_gummy_draw_entry;
-	functions->draw_progressbar_trough  = clearlooks_gummy_draw_progressbar_trough;
-	functions->draw_progressbar_fill    = clearlooks_gummy_draw_progressbar_fill;
-	functions->draw_scale_trough        = clearlooks_gummy_draw_scale_trough;
-	functions->draw_tab                 = clearlooks_gummy_draw_tab;
-	functions->draw_separator           = clearlooks_gummy_draw_separator;
-	functions->draw_slider              = clearlooks_gummy_draw_slider;
-	functions->draw_slider_button       = clearlooks_gummy_draw_slider_button;
-	functions->draw_scrollbar_stepper   = clearlooks_gummy_draw_scrollbar_stepper;
-	functions->draw_scrollbar_slider    = clearlooks_gummy_draw_scrollbar_slider;
-	functions->draw_list_view_header    = clearlooks_gummy_draw_list_view_header;
-	functions->draw_toolbar             = clearlooks_gummy_draw_toolbar;
-	functions->draw_menuitem            = clearlooks_gummy_draw_menuitem;
-	functions->draw_menubaritem         = clearlooks_gummy_draw_menubaritem;
-	functions->draw_selected_cell       = clearlooks_gummy_draw_selected_cell;
-	functions->draw_statusbar           = clearlooks_gummy_draw_statusbar;
-	functions->draw_checkbox            = clearlooks_gummy_draw_checkbox;
-	functions->draw_radiobutton         = clearlooks_gummy_draw_radiobutton;
+	functions->draw_button             = clearlooks_gummy_draw_button;
+	functions->draw_entry              = clearlooks_gummy_draw_entry;
+	functions->draw_progressbar_trough = clearlooks_gummy_draw_progressbar_trough;
+	functions->draw_progressbar_fill   = clearlooks_gummy_draw_progressbar_fill;
+	functions->draw_scale_trough       = clearlooks_gummy_draw_scale_trough;
+	functions->draw_tab                = clearlooks_gummy_draw_tab;
+	functions->draw_separator          = clearlooks_gummy_draw_separator;
+	functions->draw_slider             = clearlooks_gummy_draw_slider;
+	functions->draw_slider_button      = clearlooks_gummy_draw_slider_button;
+	functions->draw_scrollbar_stepper  = clearlooks_gummy_draw_scrollbar_stepper;
+	functions->draw_scrollbar_slider   = clearlooks_gummy_draw_scrollbar_slider;
+	functions->draw_list_view_header   = clearlooks_gummy_draw_list_view_header;
+	functions->draw_toolbar            = clearlooks_gummy_draw_toolbar;
+	functions->draw_menuitem           = clearlooks_gummy_draw_menuitem;
+	functions->draw_menubaritem        = clearlooks_gummy_draw_menubaritem;
+	functions->draw_selected_cell      = clearlooks_gummy_draw_selected_cell;
+	functions->draw_statusbar          = clearlooks_gummy_draw_statusbar;
+	functions->draw_checkbox           = clearlooks_gummy_draw_checkbox;
+	functions->draw_radiobutton        = clearlooks_gummy_draw_radiobutton;
+	functions->draw_focus              = clearlooks_gummy_draw_focus;
 }
